@@ -14,7 +14,7 @@ use strict;
 use warnings;
 
 BEGIN {
-  $REST::Neo4p::VERSION = '0.3004';
+  $REST::Neo4p::VERSION = '0.3010';
 }
 
 our $CREATE_AUTO_ACCESSORS = 0;
@@ -125,8 +125,10 @@ sub agent {
 sub connect {
   my $neo4p = shift;
   my ($server_address, $user, $pass) = @_;
+  $HANDLES[$HANDLE]->{_user} = $user;
+  $HANDLES[$HANDLE]->{_pass} = $pass;
   REST::Neo4p::LocalException->throw("Server address not set\n")  unless $server_address;
-  $neo4p->agent->credentials($server_address,'',$user,$pass) if defined $user;
+  $neo4p->agent->credentials($server_address,'Neo4j',$user,$pass) if defined $user;
   my $connected = $neo4p->agent->connect($server_address);
   return $HANDLES[$HANDLE]->{_connected} = $connected;
 }
@@ -549,7 +551,7 @@ C<LWP::UserAgent> by default.
 
 =item agent()
 
- REST::Neo4p->agent->credentials( $server, '', $user, $pass);
+ REST::Neo4p->agent->credentials( $server, 'Neo4j', $user, $pass);
  REST::Neo4p->connect($server);
 
 Returns the underlying L<REST::Neo4p::Agent> object.
@@ -666,7 +668,7 @@ L<REST::Neo4p::Schema>,L<REST::Neo4p::Constrain>, L<REST::Neo4p::Constraint>.
 
 =head1 LICENSE
 
-Copyright (c) 2012-2014 Mark A. Jensen. This program is free software; you
+Copyright (c) 2012-2015 Mark A. Jensen. This program is free software; you
 can redistribute it and/or modify it under the same terms as Perl
 itself.
 
