@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 BEGIN {
-  $REST::Neo4p::Exceptions::VERSION = '0.3004';
+  $REST::Neo4p::Exceptions::VERSION = '0.3010';
 }
 use Exception::Class (
   'REST::Neo4p::Exception',
@@ -25,6 +25,12 @@ use Exception::Class (
     fields => [ 'code' ],
     description => 'Network or HTTP errors'
    },
+  'REST::Neo4p::AuthException' =>
+    {
+    isa => 'REST::Neo4p::Exception',
+    fields => [ 'code', 'message' ],
+    description => 'Authorization error'
+   },
   'REST::Neo4p::NotFoundException' => {
     isa => 'REST::Neo4p::Neo4jException',
     fields => [ 'code', 'neo4j_message', 
@@ -202,7 +208,7 @@ L<REST::Neo4p>, L<Exception::Class>
 
 =head1 LICENSE
 
-Copyright (c) 2012-2014 Mark A. Jensen. This program is free software; you
+Copyright (c) 2012-2015 Mark A. Jensen. This program is free software; you
 can redistribute it and/or modify it under the same terms as Perl
 itself.
 
